@@ -1,20 +1,22 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for es service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.es import ElasticsearchServiceClient
-
-    session = boto3.Session()
+    from mypy_boto3_es import ElasticsearchServiceClient
 
     client: ElasticsearchServiceClient = boto3.client("es")
-    session_client: ElasticsearchServiceClient = session.client("es")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_es.paginator import (
     DescribeReservedElasticsearchInstanceOfferingsPaginator,
     DescribeReservedElasticsearchInstancesPaginator,
@@ -100,7 +102,7 @@ class Exceptions:
 
 class ElasticsearchServiceClient:
     """
-    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client)
+    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client)
     """
 
     exceptions: Exceptions
@@ -109,29 +111,29 @@ class ElasticsearchServiceClient:
         self, CrossClusterSearchConnectionId: str
     ) -> AcceptInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.accept_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        [Client.accept_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
         """
 
     def add_tags(self, ARN: str, TagList: List["TagTypeDef"]) -> None:
         """
-        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.add_tags)
         """
 
     def associate_package(self, PackageID: str, DomainName: str) -> AssociatePackageResponseTypeDef:
         """
-        [Client.associate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Client.associate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.associate_package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.can_paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> CancelElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
         """
 
     def create_elasticsearch_domain(
@@ -155,7 +157,7 @@ class ElasticsearchServiceClient:
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
-        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
         """
 
     def create_outbound_cross_cluster_search_connection(
@@ -165,7 +167,7 @@ class ElasticsearchServiceClient:
         ConnectionAlias: str,
     ) -> CreateOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.create_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
+        [Client.create_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
         """
 
     def create_package(
@@ -176,59 +178,59 @@ class ElasticsearchServiceClient:
         PackageDescription: str = None,
     ) -> CreatePackageResponseTypeDef:
         """
-        [Client.create_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Client.create_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.create_package)
         """
 
     def delete_elasticsearch_domain(
         self, DomainName: str
     ) -> DeleteElasticsearchDomainResponseTypeDef:
         """
-        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
         """
-        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
         """
 
     def delete_inbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> DeleteInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.delete_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        [Client.delete_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
         """
 
     def delete_outbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> DeleteOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.delete_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
+        [Client.delete_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
         """
 
     def delete_package(self, PackageID: str) -> DeletePackageResponseTypeDef:
         """
-        [Client.delete_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Client.delete_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.delete_package)
         """
 
     def describe_elasticsearch_domain(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
         """
 
     def describe_elasticsearch_domain_config(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
         """
 
     def describe_elasticsearch_domains(
         self, DomainNames: List[str]
     ) -> DescribeElasticsearchDomainsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
         """
 
     def describe_elasticsearch_instance_type_limits(
@@ -297,21 +299,21 @@ class ElasticsearchServiceClient:
         DomainName: str = None,
     ) -> DescribeElasticsearchInstanceTypeLimitsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
         """
 
     def describe_inbound_cross_cluster_search_connections(
         self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeInboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Client.describe_inbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        [Client.describe_inbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
         """
 
     def describe_outbound_cross_cluster_search_connections(
         self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Client.describe_outbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
+        [Client.describe_outbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
         """
 
     def describe_packages(
@@ -321,7 +323,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribePackagesResponseTypeDef:
         """
-        [Client.describe_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Client.describe_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_packages)
         """
 
     def describe_reserved_elasticsearch_instance_offerings(
@@ -331,7 +333,7 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
         """
 
     def describe_reserved_elasticsearch_instances(
@@ -341,14 +343,14 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstancesResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
         """
 
     def dissociate_package(
         self, PackageID: str, DomainName: str
     ) -> DissociatePackageResponseTypeDef:
         """
-        [Client.dissociate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Client.dissociate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
         """
 
     def generate_presigned_url(
@@ -359,38 +361,38 @@ class ElasticsearchServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
         """
 
     def get_compatible_elasticsearch_versions(
         self, DomainName: str = None
     ) -> GetCompatibleElasticsearchVersionsResponseTypeDef:
         """
-        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
         """
 
     def get_upgrade_history(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
         """
 
     def get_upgrade_status(self, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
         """
 
     def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
         """
-        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
         """
 
     def list_domains_for_package(
         self, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> ListDomainsForPackageResponseTypeDef:
         """
-        [Client.list_domains_for_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Client.list_domains_for_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
         """
 
     def list_elasticsearch_instance_types(
@@ -401,26 +403,26 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> ListElasticsearchInstanceTypesResponseTypeDef:
         """
-        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
         """
 
     def list_elasticsearch_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListElasticsearchVersionsResponseTypeDef:
         """
-        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
         """
 
     def list_packages_for_domain(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListPackagesForDomainResponseTypeDef:
         """
-        [Client.list_packages_for_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Client.list_packages_for_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
         """
 
     def list_tags(self, ARN: str) -> ListTagsResponseTypeDef:
         """
-        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.list_tags)
         """
 
     def purchase_reserved_elasticsearch_instance_offering(
@@ -430,26 +432,26 @@ class ElasticsearchServiceClient:
         InstanceCount: int = None,
     ) -> PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef:
         """
-        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
         """
 
     def reject_inbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> RejectInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.reject_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
+        [Client.reject_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
         """
 
     def remove_tags(self, ARN: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.remove_tags)
         """
 
     def start_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> StartElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
         """
 
     def update_elasticsearch_domain_config(
@@ -470,14 +472,14 @@ class ElasticsearchServiceClient:
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
         """
 
     def upgrade_elasticsearch_domain(
         self, DomainName: str, TargetVersion: str, PerformCheckOnly: bool = None
     ) -> UpgradeElasticsearchDomainResponseTypeDef:
         """
-        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
         """
 
     @overload
@@ -485,7 +487,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
         """
 
     @overload
@@ -493,7 +495,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
         """
 
     @overload
@@ -501,7 +503,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
         """
 
     @overload
@@ -509,7 +511,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
         """
 
     @overload
@@ -517,5 +519,8 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
