@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for es service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.es import (
+
+    from mypy_boto3_es import ElasticsearchServiceClient
+    from mypy_boto3_es.paginator import (
         DescribeReservedElasticsearchInstanceOfferingsPaginator,
         DescribeReservedElasticsearchInstancesPaginator,
         GetUpgradeHistoryPaginator,
@@ -19,10 +23,12 @@ Usage::
     get_upgrade_history_paginator: GetUpgradeHistoryPaginator = client.get_paginator("get_upgrade_history")
     list_elasticsearch_instance_types_paginator: ListElasticsearchInstanceTypesPaginator = client.get_paginator("list_elasticsearch_instance_types")
     list_elasticsearch_versions_paginator: ListElasticsearchVersionsPaginator = client.get_paginator("list_elasticsearch_versions")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_es.type_defs import (
     DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef,
     DescribeReservedElasticsearchInstancesResponseTypeDef,
@@ -32,7 +38,6 @@ from mypy_boto3_es.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "DescribeReservedElasticsearchInstanceOfferingsPaginator",
     "DescribeReservedElasticsearchInstancesPaginator",
@@ -44,7 +49,7 @@ __all__ = (
 
 class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+    [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
     """
 
     def paginate(
@@ -53,13 +58,13 @@ class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef]:
         """
-        [DescribeReservedElasticsearchInstanceOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings.paginate)
+        [DescribeReservedElasticsearchInstanceOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings.paginate)
         """
 
 
 class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+    [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
     """
 
     def paginate(
@@ -68,26 +73,26 @@ class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeReservedElasticsearchInstancesResponseTypeDef]:
         """
-        [DescribeReservedElasticsearchInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances.paginate)
+        [DescribeReservedElasticsearchInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances.paginate)
         """
 
 
 class GetUpgradeHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+    [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
     """
 
     def paginate(
         self, DomainName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetUpgradeHistoryResponseTypeDef]:
         """
-        [GetUpgradeHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory.paginate)
+        [GetUpgradeHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory.paginate)
         """
 
 
 class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+    [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
     """
 
     def paginate(
@@ -97,18 +102,18 @@ class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListElasticsearchInstanceTypesResponseTypeDef]:
         """
-        [ListElasticsearchInstanceTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes.paginate)
+        [ListElasticsearchInstanceTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes.paginate)
         """
 
 
 class ListElasticsearchVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+    [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListElasticsearchVersionsResponseTypeDef]:
         """
-        [ListElasticsearchVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions.paginate)
+        [ListElasticsearchVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions.paginate)
         """
